@@ -1,5 +1,6 @@
 """SatNOGS DB Auth0 login module auth backend"""
 import requests
+from jose import jwt
 from social_core.backends.oauth import BaseOAuth2
 
 
@@ -8,6 +9,7 @@ class Auth0(BaseOAuth2):
     name = 'auth0'
     SCOPE_SEPARATOR = ' '
     ACCESS_TOKEN_METHOD = 'POST'
+    REDIRECT_STATE = False
     EXTRA_DATA = [('email', 'email')]
 
     def authorization_url(self):
@@ -27,14 +29,19 @@ class Auth0(BaseOAuth2):
         return details['user_id']
 
     def get_user_details(self, response):
-        url = 'https://' + self.setting('DOMAIN') + '/userinfo'
-        headers = {'authorization': 'Bearer ' + response['access_token']}
-        resp = requests.get(url, headers=headers)
-        userinfo = resp.json()
+        # Obtain JWT and the keys to validate the signature
+        id_token = response.get('id_token')
+        jwks = requests.get('https://' + self.setting('DOMAIN') + '/.well-known/jwks.json')
+        issuer = 'https://' + self.setting('DOMAIN') + '/'
+        audience = self.setting('KEY')  # CLIENT_ID
+        payload = jwt.decode(
+            id_token, jwks.json(), algorithms=['RS256'], audience=audience, issuer=issuer
+        )
 
         return {
-            'username': userinfo['nickname'],
-            'email': userinfo['email'],
-            # 'first_name': userinfo['name'],
-            'user_id': userinfo['sub']
+            'username': payload['nickname'],
+            # 'first_name': payload['name'],
+            # 'picture': payload['picture'],
+            'user_id': payload['sub'],
+            'email': payload['email']
         }
