@@ -1,8 +1,8 @@
-from django.db import models, migrations
-from django.conf import settings
+import django.core.validators
 import django.db.models.deletion
 import shortuuidfield.fields
-import django.core.validators
+from django.conf import settings
+from django.db import migrations, models
 
 
 class Migration(migrations.Migration):
