@@ -341,15 +341,11 @@ class TransmitterEntry(models.Model):
     satellite = models.ForeignKey(
         Satellite, null=True, related_name='transmitter_entries', on_delete=models.SET_NULL
     )
-    reviewed = models.BooleanField(default=False)
-    approved = models.BooleanField(default=False)
-    created = models.DateTimeField(default=now, help_text='Timestamp for this entry or edit')
     citation = models.CharField(
         max_length=512,
         default='CITATION NEEDED - https://xkcd.com/285/',
         help_text='A reference (preferrably URL) for this entry or edit'
     )
-    user = models.ForeignKey(get_user_model(), null=True, on_delete=models.SET_NULL)
     service = models.CharField(
         choices=zip(SERVICE_TYPE, SERVICE_TYPE),
         max_length=34,
@@ -368,6 +364,22 @@ class TransmitterEntry(models.Model):
         help_text='URL for more details on this frequency coordination',
         validators=[URLValidator(schemes=['http', 'https'], regex=URL_REGEX)]
     )
+    reviewer = models.ForeignKey(
+        get_user_model(),
+        related_name='reviewed_transmitters',
+        blank=True,
+        null=True,
+        on_delete=models.SET_NULL
+    )
+    reviewed = models.DateTimeField(blank=True, null=True, help_text='Timestamp of review')
+    approved = models.BooleanField(default=False)
+    created = models.DateTimeField(default=now, help_text='Timestamp of creation/edit')
+    created_by = models.ForeignKey(
+        get_user_model(),
+        related_name='created_transmitters',
+        null=True,
+        on_delete=models.SET_NULL
+    )
 
     # NOTE: future fields will need to be added to forms.py and to
     # api/serializers.py
@@ -384,19 +396,12 @@ class TransmitterEntry(models.Model):
         return False
 
     class Meta:
-        unique_together = ("uuid", "created")
+        unique_together = ("uuid", "reviewed")
         verbose_name_plural = 'Transmitter entries'
 
     def __str__(self):
         return self.description
 
-    # see https://github.com/PyCQA/pylint-django/issues/94
-    def save(self, *args, **kwargs):  # pylint: disable=W0222
-        # this assignment is needed to preserve changes made to a Transmitter
-        # through the admin UI
-        self.id = None  # pylint: disable=C0103, W0201
-        super().save()
-
     def clean(self):
         if self.type == TRANSMITTER_TYPE[0]:
             if self.uplink_low is not None or self.uplink_high is not None \
@@ -436,7 +441,7 @@ class TransmitterSuggestionManager(models.Manager):  # pylint: disable=R0903
     """
     def get_queryset(self):  # pylint: disable=R0201
         """Returns TransmitterEntries that have not been reviewed"""
-        return TransmitterEntry.objects.filter(reviewed=False)
+        return TransmitterEntry.objects.filter(reviewed__isnull=True)
 
 
 class TransmitterSuggestion(TransmitterEntry):
@@ -461,11 +466,11 @@ class TransmitterManager(models.Manager):  # pylint: disable=R0903
         both reviewed and approved
         """
         subquery = TransmitterEntry.objects.filter(
-            reviewed=True, approved=True
-        ).filter(uuid=OuterRef('uuid')).order_by('-created')
+            reviewed__isnull=False, approved=True
+        ).filter(uuid=OuterRef('uuid')).order_by('-reviewed')
         return super().get_queryset().filter(
-            reviewed=True, approved=True
-        ).filter(created=Subquery(subquery.values('created')[:1]))
+            reviewed__isnull=False, approved=True
+        ).filter(reviewed=Subquery(subquery.values('reviewed')[:1]))
 
 
 class Transmitter(TransmitterEntry):
