@@ -17,7 +17,7 @@ from django.core.validators import URLValidator
 from django.template.loader import render_to_string
 from django.urls import reverse
 from django.utils.timezone import make_aware
-from satellite_tle import fetch_all_tles, fetch_tle_from_celestrak
+from satellite_tle import fetch_all_tles
 from sgp4.earth_gravity import wgs72
 from sgp4.io import twoline2rv
 
@@ -37,28 +37,22 @@ def check_celery():
 
 
 @shared_task
-def update_satellite(norad_id, update_name=True):
+def update_satellite_name(norad_id):
     """Task to update the name and/or the tle of a satellite, or create a
        new satellite in the db if no satellite with given norad_id can be found"""
 
-    tle = fetch_tle_from_celestrak(norad_id)
-
-    satellite_created = False
     try:
         satellite = Satellite.objects.get(norad_cat_id=norad_id)
     except Satellite.DoesNotExist:
-        satellite_created = True
-        satellite = Satellite(norad_cat_id=norad_id)
+        return
 
-    if update_name:
-        satellite.name = tle[0]
+    if norad_id < 99000:
+        other_sources = get_tle_sources()
+        tles = fetch_all_tles({norad_id}, **other_sources)
 
-    satellite.save()
-
-    if satellite_created:
-        print('Created satellite {}: {}'.format(satellite.norad_cat_id, satellite.name))
-    else:
-        print('Updated satellite {}: {}'.format(satellite.norad_cat_id, satellite.name))
+        if norad_id in tles.keys():
+            satellite.name = tles[norad_id][0][1][0]
+            satellite.save(update_fields=['name'])
 
 
 @shared_task
@@ -76,7 +70,7 @@ def update_tle_sets():
 
     other_sources = get_tle_sources()
 
-    print("==Fetching TLEs==")
+    LOGGER.info("==Fetching TLEs==")
     tles = fetch_all_tles(catalog_norad_ids, **other_sources)
 
     for satellite in satellites:
@@ -89,10 +83,8 @@ def update_tle_sets():
                 try:
                     sgp4_tle = twoline2rv(tle[1], tle[2], wgs72)
                 except ValueError:
-                    print(
-                        '[ERROR] {} - {} - {}: TLE malformed'.format(
-                            satellite.name, norad_id, source
-                        )
+                    LOGGER.info(
+                        '[ERROR] %s - %s - %s: TLE malformed', satellite.name, norad_id, source
                     )
                     continue
 
@@ -108,10 +100,9 @@ def update_tle_sets():
                             and last_tle_from_source.tle0 == tle[0]  # noqa: W503
                             and last_tle_from_source.tle1 == tle[1]  # noqa: W503
                             and last_tle_from_source.tle2 == tle[2]):  # noqa: W503
-                        print(
-                            '[EXISTS] {} - {} - {}: TLE set already exists'.format(
-                                satellite.name, norad_id, source
-                            )
+                        LOGGER.info(
+                            '[EXISTS] %s - %s - %s: TLE set already exists', satellite.name,
+                            norad_id, source
                         )
                         continue
 
@@ -122,13 +113,11 @@ def update_tle_sets():
                     tle0=tle[0], tle1=tle[1], tle2=tle[2], satellite=satellite, tle_source=source
                 )
 
-                print(
-                    '[ADDED] {} - {} - {}: TLE set is added'.format(
-                        satellite.name, norad_id, source
-                    )
+                LOGGER.info(
+                    '[ADDED] %s - %s - %s: TLE set is added', satellite.name, norad_id, source
                 )
         else:
-            print('[NOT FOUND] {} - {}: TLE set wasn\'t found'.format(satellite.name, norad_id))
+            LOGGER.info('[NOT FOUND] %s - %s: TLE set wasn\'t found', satellite.name, norad_id)
     update_latest_tle_sets()
 
 
@@ -276,7 +265,7 @@ def publish_current_frame(timestamp, frame, observer, ids):
         publisher.recv()
     except zmq.ZMQError as error:
         if error.errno == zmq.EAGAIN:
-            print('EAGAIN error - No subscription was received')
+            LOGGER.info('EAGAIN error - No subscription was received')
         else:
             raise
     else:
