@@ -81,11 +81,12 @@ class TransmitterFactory(factory.django.DjangoModelFactory):
     invert = fuzzy.FuzzyChoice(choices=[True, False])
     baud = fuzzy.FuzzyInteger(4000, 22000, step=1000)
     satellite = factory.SubFactory(SatelliteFactory)
-    reviewed = True
     approved = True
-    created = fuzzy.FuzzyDateTime(now() - timedelta(days=30), now())
+    created = fuzzy.FuzzyDateTime(now() - timedelta(days=30), now() - timedelta(hours=10))
+    reviewed = fuzzy.FuzzyDateTime(now() - timedelta(hours=10), now())
     citation = fuzzy.FuzzyText()
-    user = factory.SubFactory(UserFactory)
+    created_by = factory.SubFactory(UserFactory)
+    reviewer = factory.SubFactory(UserFactory)
 
     class Meta:
         model = Transmitter
@@ -105,11 +106,10 @@ class TransmitterSuggestionFactory(factory.django.DjangoModelFactory):
     invert = fuzzy.FuzzyChoice(choices=[True, False])
     baud = fuzzy.FuzzyInteger(4000, 22000, step=1000)
     satellite = factory.SubFactory(SatelliteFactory)
-    reviewed = False
     approved = False
     created = fuzzy.FuzzyDateTime(now() - timedelta(days=30), now())
     citation = fuzzy.FuzzyText()
-    user = factory.SubFactory(UserFactory)
+    created_by = factory.SubFactory(UserFactory)
     service = fuzzy.FuzzyChoice(
         choices=['Amateur', 'Broadcasting', 'Earth Exploration', 'Fixed', 'Inter-satellite']
     )
